@@ -27,7 +27,7 @@ Available Commands:
   eval		Evaluate a JSON/YAML document and replace any template expressions in it and prints the result
   exec		Populates the environment variables and executes the command
   env		Renders environment variables to be consumed by eval or a tool like direnv
-  get       Evaluate a string value passed as the first argument and replace any expressiosn in it and prints the result
+  get		Evaluate a string value passed as the first argument and replace any expressions in it and prints the result
   ksdecode	Decode YAML document(s) by converting Secret resources' "data" to "stringData" for use with "vals eval"
   version	Print vals version
 
@@ -145,6 +145,8 @@ func main() {
 	case CmdExec:
 		execCmd := flag.NewFlagSet(CmdExec, flag.ExitOnError)
 		f := execCmd.String("f", "", "YAML/JSON file to be loaded to set envvars")
+		inheritEnv := execCmd.Bool("i", false, "Inherit environment variables")
+		silent := execCmd.Bool("s", false, "Silent mode")
 		streamYAML := execCmd.String("stream-yaml", "", `Reads the specific YAML file or all the YAML files
 stored within the specific directory, evaluate each YAML file,
 joining all the YAML files with "---" lines, and stream the
@@ -165,7 +167,14 @@ the vals-eval outputs onto the disk, for security reasons.`)
 			m = map[string]interface{}{}
 		}
 
+		var logOut io.Writer = os.Stderr
+		if *silent {
+			logOut = io.Discard
+		}
+
 		err = vals.Exec(m, execCmd.Args(), vals.ExecConfig{
+			InheritEnv: *inheritEnv,
+			Options:    vals.Options{LogOutput: logOut},
 			StreamYAML: *streamYAML,
 		})
 		if err != nil {
