@@ -4,6 +4,7 @@ import (
 	"fmt"
 
 	"github.com/helmfile/vals/pkg/api"
+	"github.com/helmfile/vals/pkg/log"
 	"github.com/helmfile/vals/pkg/providers/awskms"
 	"github.com/helmfile/vals/pkg/providers/awssecrets"
 	"github.com/helmfile/vals/pkg/providers/azurekeyvault"
@@ -17,24 +18,24 @@ import (
 	"github.com/helmfile/vals/pkg/providers/vault"
 )
 
-func New(provider api.StaticConfig) (api.LazyLoadedStringProvider, error) {
+func New(l *log.Logger, provider api.StaticConfig) (api.LazyLoadedStringProvider, error) {
 	tpe := provider.String("name")
 
 	switch tpe {
 	case "s3":
-		return s3.New(provider), nil
+		return s3.New(l, provider), nil
 	case "gcs":
 		return gcs.New(provider), nil
 	case "ssm":
-		return ssm.New(provider), nil
+		return ssm.New(l, provider), nil
 	case "vault":
-		return vault.New(provider), nil
+		return vault.New(l, provider), nil
 	case "awskms":
 		return awskms.New(provider), nil
 	case "awssecrets":
-		return awssecrets.New(provider), nil
+		return awssecrets.New(l, provider), nil
 	case "sops":
-		return sops.New(provider), nil
+		return sops.New(l, provider), nil
 	case "gcpsecrets":
 		return gcpsecrets.New(provider), nil
 	case "tfstate":
